@@ -24,6 +24,9 @@
 #include "MetaData.h"
 #include "ObsTable.h"
 #include "ProgressObject.h"
+#include "MagicsGlobal.h"
+
+
 using namespace magics;
 
 ObsPlotting::ObsPlotting() {
@@ -52,6 +55,9 @@ void ObsPlotting::operator()(Data& data, BasicGraphicsObjectContainer& out) {
             obs.visit(needs);
         }
         catch (std::exception&) {
+            if (MagicsGlobal::strict()) {
+                throw;
+            }
             MagLog::warning() << " Magics++ has no observation template for: " << type->second << "\n"
                               << " Please contact the Graphic team.\n";
         }
@@ -77,6 +83,9 @@ void ObsPlotting::operator()(Data& data, BasicGraphicsObjectContainer& out) {
             }
         }
         catch (std::exception&) {
+            if (MagicsGlobal::strict()) {
+                throw;
+            }
         }
     }
 }
